@@ -18,7 +18,8 @@
 
 import os
 import re
-from flask_babel import gettext as _
+
+from flask_babel import lazy_gettext as N_
 
 from . import config, logger
 from .subproc_wrapper import process_wait
@@ -26,9 +27,9 @@ from .subproc_wrapper import process_wait
 
 log = logger.create()
 
-# _() necessary to make babel aware of string for translation
-_NOT_INSTALLED = _('not installed')
-_EXECUTION_ERROR = _('Execution permissions missing')
+# strings getting translated when used
+_NOT_INSTALLED = N_('not installed')
+_EXECUTION_ERROR = N_('Execution permissions missing')
 
 
 def _get_command_version(path, pattern, argument=None):
@@ -53,10 +54,9 @@ def get_calibre_version():
 def get_unrar_version():
     unrar_version = _get_command_version(config.config_rarfile_location, r'UNRAR.*\d')
     if unrar_version == "not installed":
-        unrar_version = _get_command_version(config.config_rarfile_location, r'unrar.*\d','-V')
+        unrar_version = _get_command_version(config.config_rarfile_location, r'unrar.*\d', '-V')
     return unrar_version
 
+
 def get_kepubify_version():
-    return _get_command_version(config.config_kepubifypath, r'kepubify\s','--version')
-
-
+    return _get_command_version(config.config_kepubifypath, r'kepubify\s', '--version')
