@@ -19,6 +19,7 @@
 # Google Books api document: https://developers.google.com/books/docs/v1/using
 from typing import Dict, List, Optional
 from urllib.parse import quote
+from datetime import datetime
 
 import requests
 
@@ -81,7 +82,11 @@ class Google(Metadata):
         match.description = result["volumeInfo"].get("description", "")
         match.languages = self._parse_languages(result=result, locale=locale)
         match.publisher = result["volumeInfo"].get("publisher", "")
-        match.publishedDate = result["volumeInfo"].get("publishedDate", "")
+        try:
+            datetime.strptime(result["volumeInfo"].get("publishedDate", ""), "%Y-%m-%d")
+            match.publishedDate = result["volumeInfo"].get("publishedDate", "")
+        except ValueError:
+            match.publishedDate = ""
         match.rating = result["volumeInfo"].get("averageRating", 0)
         match.series, match.series_index = "", 1
         match.tags = result["volumeInfo"].get("categories", [])
@@ -103,6 +108,13 @@ class Google(Metadata):
     def _parse_cover(result: Dict, generic_cover: str) -> str:
         if result["volumeInfo"].get("imageLinks"):
             cover_url = result["volumeInfo"]["imageLinks"]["thumbnail"]
+            
+            # strip curl in cover
+            cover_url = cover_url.replace("&edge=curl", "")
+            
+            # request 800x900 cover image (higher resolution)
+            cover_url += "&fife=w800-h900"
+            
             return cover_url.replace("http://", "https://")
         return generic_cover
 
