@@ -85,14 +85,6 @@ $(document).on("change", "select[data-controlall]", function() {
     }
 });
 
-/*$(document).on("click", "#sendbtn", function (event) {
-    postButton(event, $(this).data('action'));
-});
-
-$(document).on("click", ".sendbutton", function (event) {
-    // $(".sendbutton").on("click", "body", function(event) {
-    postButton(event, $(this).data('action'));
-});*/
 
 $(document).on("click", ".postAction", function (event) {
     // $(".sendbutton").on("click", "body", function(event) {
@@ -100,7 +92,6 @@ $(document).on("click", ".postAction", function (event) {
 });
 
 
-
 // Syntax has to be bind not on, otherwise problems with firefox
 $(".container-fluid").bind("dragenter dragover", function () {
     if($("#btn-upload").length && !$('body').hasClass('shelforder')) {
@@ -151,13 +142,13 @@ $("#form-upload").uploadprogress({
 });
 
 $(document).ready(function() {
-  var inp = $('#query').first()
-  if (inp.length) {
-    var val = inp.val()
-    if (val.length) {
-      inp.val('').blur().focus().val(val)
+    var inp = $('#query').first()
+    if (inp.length) {
+        var val = inp.val()
+        if (val.length) {
+            inp.val('').blur().focus().val(val)
+        }
     }
-  }
 });
 
 $(".session").click(function() {
@@ -313,7 +304,7 @@ $(function() {
     }
 
     function fillFileTable(path, type, folder, filt) {
-        var request_path = "/../../ajax/pathchooser/";
+        var request_path = "/ajax/pathchooser/";
         $.ajax({
             dataType: "json",
             data: {
@@ -321,7 +312,7 @@ $(function() {
                 folder: folder,
                 filter: filt
             },
-            url: window.location.pathname + request_path,
+            url: getPath() + request_path,
             success: function success(data) {
                 if ($("#element_selected").text() ==="") {
                     $("#element_selected").text(data.cwd);
@@ -364,12 +355,6 @@ $(function() {
         layoutMode : "fitRows"
     });
 
-    $(".grid").isotope({
-        // options
-        itemSelector : ".grid-item",
-        layoutMode : "fitColumns"
-    });
-
     if ($(".load-more").length && $(".next").length) {
         var $loadMore = $(".load-more .row").infiniteScroll({
             debug: false,
@@ -440,7 +425,7 @@ $(function() {
         }
         $.ajax({
             dataType: "json",
-            url: window.location.pathname + "/../../get_update_status",
+            url: getPath() + "/get_update_status",
             success: function success(data) {
                 $this.html(buttonText);
 
@@ -503,6 +488,23 @@ $(function() {
             }
         });
     });
+    $("#metadata_backup").click(function() {
+        $("#DialogHeader").addClass("hidden");
+        $("#DialogFinished").addClass("hidden");
+        $("#DialogContent").html("");
+        $("#spinner2").show();
+        $.ajax({
+            method: "post",
+            contentType: "application/json; charset=utf-8",
+            dataType: "json",
+            url: getPath() + "/metadata_backup",
+            success: function success(data) {
+                $("#spinner2").hide();
+                $("#DialogContent").html(data.text);
+                $("#DialogFinished").removeClass("hidden");
+            }
+        });
+    });
     $("#perform_update").click(function() {
         $("#DialogHeader").removeClass("hidden");
         $("#spinner2").show();
@@ -527,6 +529,7 @@ $(function() {
     $("#bookDetailsModal")
         .on("show.bs.modal", function(e) {
             $("#flash_danger").remove();
+            $("#flash_success").remove();
             var $modalBody = $(this).find(".modal-body");
 
             // Prevent static assets from loading multiple times
@@ -639,7 +642,6 @@ $(function() {
         );
     });
 
-
     $("#user_submit").click(function() {
         this.closest("form").submit();
     });
@@ -671,7 +673,7 @@ $(function() {
         $.ajax({
             method:"post",
             dataType: "json",
-            url: window.location.pathname + "/../../ajax/simulatedbchange",
+            url: getPath() + "/ajax/simulatedbchange",
             data: {config_calibre_dir: $("#config_calibre_dir").val(), csrf_token: $("input[name='csrf_token']").val()},
             success: function success(data) {
                 if ( data.change ) {
@@ -698,17 +700,16 @@ $(function() {
         e.stopPropagation();
         this.blur();
         window.scrollTo({top: 0, behavior: 'smooth'});
-        var request_path = "/../../admin/ajaxconfig";
-        var loader = "/../..";
+        var request_path = "/admin/ajaxconfig";
         $("#flash_success").remove();
         $("#flash_danger").remove();
-        $.post(window.location.pathname + request_path, $(this).closest("form").serialize(), function(data) {
+        $.post(getPath() + request_path, $(this).closest("form").serialize(), function(data) {
             $('#config_upload_formats').val(data.config_upload);
             if(data.reboot) {
                 $("#spinning_success").show();
                 var rebootInterval = setInterval(function(){
                     $.get({
-                        url:window.location.pathname + "/../../admin/alive",
+                        url:getPath() + "/admin/alive",
                         success: function (d, statusText, xhr) {
                             if (xhr.status < 400) {
                                 $("#spinning_success").hide();
@@ -734,7 +735,6 @@ $(function() {
             $(this).data('value'),
             function(value){
                 postButton(event, $("#delete_shelf").data("action"));
-                // $("#delete_shelf").closest("form").submit()
             }
         );
 
